@@ -30,7 +30,7 @@ class TestResourceDictionaryUnit(test_monolingual.TestMonolingualUnit):
 class TestResourceDictionaryFile(test_monolingual.TestMonolingualStore):
     StoreClass = resourcedictionary.ResourceDictionaryFile
 
-    def test_roundtrip(self):
+    def test_roundtrip(self) -> None:
         """Test that parser fails on inconsistent root name configuration."""
         xmlsource = """<ResourceDictionary xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation" xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml" xmlns:system="clr-namespace:System;assembly=mscorlib">
     <system:String x:Key="ApplicationNameShort">Weblate</system:String>
