@@ -24,6 +24,8 @@ import re
 import sys
 import traceback
 from io import BytesIO
+from types import TracebackType
+from typing import Any
 
 from translate import __version__
 from translate.misc import progressbar
@@ -38,7 +40,7 @@ class ProgressBar:
         "verbose": progressbar.VerboseProgressBar,
     }
 
-    def __init__(self, progress_type, allfiles):
+    def __init__(self, progress_type, allfiles) -> None:
         """Set up a progress bar appropriate to the progress_type and files."""
         if progress_type in {"bar", "verbose"}:
             file_count = len(allfiles)
@@ -56,7 +58,7 @@ class ProgressBar:
         else:
             self._progressbar = self.progress_types[progress_type]()
 
-    def report_progress(self, filename, success):
+    def report_progress(self, filename, success) -> None:
         """Show that we are progressing..."""
         self._progressbar.amount += 1
         self._progressbar.show(filename)
@@ -76,7 +78,7 @@ class ManPageOption(optparse.Option):
 class ManHelpFormatter(optparse.HelpFormatter):
     def __init__(
         self, indent_increment=0, max_help_position=0, width=80, short_first=1
-    ):
+    ) -> None:
         super().__init__(indent_increment, max_help_position, width, short_first)
 
     def format_option_strings(self, option):
@@ -96,13 +98,13 @@ class ManHelpFormatter(optparse.HelpFormatter):
 
 
 class StdoutWrapper:
-    def __init__(self):
+    def __init__(self) -> None:
         self.out = sys.stdout
 
     def __getattr__(self, name):
         return getattr(self.out, name)
 
-    def write(self, content):
+    def write(self, content) -> None:
         if isinstance(content, bytes):
             try:
                 self.out.write(content.decode("utf-8"))
@@ -116,12 +118,15 @@ class RecursiveOptionParser(optparse.OptionParser):
     """A specialized Option Parser for recursing through directories."""
 
     def __init__(
-        self, formats, usetemplates=False, allowmissingtemplate=False, description=None
-    ):
+        self,
+        formats: dict,
+        usetemplates: bool = False,
+        allowmissingtemplate: bool = False,
+        description: str | None = None,
+    ) -> None:
         """
         Construct the specialized Option Parser.
 
-        :type formats: Dictionary
         :param formats: See :meth:`~.RecursiveOptionParser.setformats`
         for an explanation of the formats parameter.
         """
@@ -137,7 +142,7 @@ class RecursiveOptionParser(optparse.OptionParser):
     def get_prog_name(self):
         return os.path.basename(sys.argv[0])
 
-    def setmanpageoption(self):
+    def setmanpageoption(self) -> None:
         """
         Creates a manpage option that allows the optionparser to generate a
         manpage.
@@ -203,36 +208,47 @@ class RecursiveOptionParser(optparse.OptionParser):
             )
         return "".join(result)
 
-    def print_manpage(self, file=None):
+    def print_manpage(self, file=None) -> None:
         """Outputs a manpage for the program using the help information."""
         if file is None:
             file = sys.stdout
         file.write(self.format_manpage())
 
-    def set_usage(self, usage=None):
+    def set_usage(self, usage=None) -> None:
         """
         Sets the usage string - if usage not given, uses getusagestring for
         each option.
         """
         if usage is None:
-            self.usage = "%prog " + " ".join(
-                self.getusagestring(option) for option in self.option_list
-            )
+            self.usage = f"%prog {' '.join(self.getusagestring(option) for option in self.option_list)}"
         else:
             super().set_usage(usage)
 
-    def warning(self, msg, options=None, exc_info=None):
+    def warning(
+        self,
+        msg,
+        options=None,
+        exc_info: tuple[type[BaseException], BaseException, TracebackType]
+        | tuple[None, None, None]
+        | None = None,
+    ) -> None:
         """Print a warning message incorporating 'msg' to stderr."""
         if options:
             if options.errorlevel == "traceback":
+                assert exc_info is not None
+                assert exc_info[0] is not None
                 errorinfo = "\n".join(
                     traceback.format_exception(exc_info[0], exc_info[1], exc_info[2])
                 )
             elif options.errorlevel == "exception":
+                assert exc_info is not None
+                assert exc_info[0] is not None
                 errorinfo = "\n".join(
                     traceback.format_exception_only(exc_info[0], exc_info[1])
                 )
             elif options.errorlevel == "message":
+                assert exc_info is not None
+                assert exc_info[1] is not None
                 errorinfo = str(exc_info[1])
             else:
                 errorinfo = ""
@@ -264,7 +280,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             return optionstring
         return f"\\fR[\\fP{optionstring}\\fR]\\fP"
 
-    def define_option(self, option):
+    def define_option(self, option) -> None:
         """
         Defines the given option, replacing an existing one of the same
         short name if necessary...
@@ -277,11 +293,12 @@ class RecursiveOptionParser(optparse.OptionParser):
                 self.remove_option(long_opt)
         self.add_option(option)
 
-    def setformats(self, formats, usetemplates):
+    def setformats(
+        self, formats: dict | list[tuple[Any, Any]], usetemplates: bool
+    ) -> None:
         """
         Sets the format options using the given format dictionary.
 
-        :type formats: Dictionary or iterable
         :param formats: The dictionary *keys* should be:
 
                         - Single strings (or 1-tuples) containing an
@@ -299,9 +316,10 @@ class RecursiveOptionParser(optparse.OptionParser):
         templateformats = []
         self.outputoptions = {}
         self.usetemplates = usetemplates
-        if isinstance(formats, dict):
-            formats = formats.items()
-        for formatgroup, outputoptions in formats:
+        format_items: list[tuple[Any, Any]] = (
+            list(formats.items()) if isinstance(formats, dict) else formats
+        )
+        for formatgroup, outputoptions in format_items:
             if isinstance(formatgroup, str) or formatgroup is None:
                 formatgroup = (formatgroup,)
             if not isinstance(formatgroup, tuple):
@@ -334,8 +352,8 @@ class RecursiveOptionParser(optparse.OptionParser):
             metavar="INPUT",
             help=f"read from INPUT in {inputformathelp}",
         )
-        inputoption.optionalswitch = True
-        inputoption.required = True
+        inputoption.optionalswitch = True  # type: ignore[attr-defined]
+        inputoption.required = True  # type: ignore[attr-defined]
         self.define_option(inputoption)
         excludeoption = optparse.Option(
             "-x",
@@ -357,8 +375,8 @@ class RecursiveOptionParser(optparse.OptionParser):
             metavar="OUTPUT",
             help=f"write to OUTPUT in {outputformathelp}",
         )
-        outputoption.optionalswitch = True
-        outputoption.required = True
+        outputoption.optionalswitch = True  # type: ignore[attr-defined]
+        outputoption.required = True  # type: ignore[attr-defined]
         self.define_option(outputoption)
         if self.usetemplates:
             self.templateformats = templateformats
@@ -373,7 +391,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             )
             self.define_option(templateoption)
 
-    def setprogressoptions(self):
+    def setprogressoptions(self) -> None:
         """Sets the progress options."""
         progressoption = optparse.Option(
             None,
@@ -382,11 +400,11 @@ class RecursiveOptionParser(optparse.OptionParser):
             default="bar",
             choices=list(ProgressBar.progress_types.keys()),
             metavar="PROGRESS",
-            help="show progress as: {}".format(", ".join(ProgressBar.progress_types)),
+            help=f"show progress as: {', '.join(ProgressBar.progress_types)}",
         )
         self.define_option(progressoption)
 
-    def seterrorleveloptions(self):
+    def seterrorleveloptions(self) -> None:
         """Sets the errorlevel options."""
         self.errorleveltypes = ["none", "message", "exception", "traceback"]
         errorleveloption = optparse.Option(
@@ -396,19 +414,19 @@ class RecursiveOptionParser(optparse.OptionParser):
             default="message",
             choices=self.errorleveltypes,
             metavar="ERRORLEVEL",
-            help="show errorlevel as: {}".format(", ".join(self.errorleveltypes)),
+            help=f"show errorlevel as: {', '.join(self.errorleveltypes)}",
         )
         self.define_option(errorleveloption)
 
     @staticmethod
-    def getformathelp(formats):
+    def getformathelp(formats) -> str:
         """Make a nice help string for describing formats..."""
         formats = sorted(f for f in formats if f is not None)
         if len(formats) == 0:
             return ""
         if len(formats) == 1:
-            return "{} format".format(", ".join(formats))
-        return "{} formats".format(", ".join(formats))
+            return f"{', '.join(formats)} format"
+        return f"{', '.join(formats)} formats"
 
     @staticmethod
     def isrecursive(fileoption, filepurpose="input"):
@@ -493,14 +511,17 @@ class RecursiveOptionParser(optparse.OptionParser):
                     )
                 if templateext is None:
                     raise ValueError(
-                        "don't know what to do with input format %s, no template file"
-                        % (os.extsep + inputext)
+                        f"don't know what to do with input format {os.extsep + inputext}, no template file"
                     )
                 raise ValueError(
                     f"don't know what to do with input format {os.extsep + inputext}, template format {os.extsep + templateext}"
                 )
+            if inputext is None:
+                raise ValueError(
+                    "don't know what to do with input format (no file extension)"
+                )
             raise ValueError(
-                "don't know what to do with input format %s" % (os.extsep + inputext)
+                f"don't know what to do with input format {os.extsep + inputext}"
             )
         if outputformat == "*":
             if inputext:
@@ -541,7 +562,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             return os.path.join(options.template, templatepath)
         return None
 
-    def run(self):
+    def run(self) -> None:
         """
         Parses the arguments, and runs recursiveprocess with the resulting
         options...
@@ -549,7 +570,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         (options, _args) = self.parse_args()
         self.recursiveprocess(options)
 
-    def recursiveprocess(self, options):
+    def recursiveprocess(self, options) -> None:
         """Recurse through directories and process files."""
         if self.isrecursive(options.input, "input") and getattr(
             options, "allowrecursiveinput", True
@@ -621,19 +642,15 @@ class RecursiveOptionParser(optparse.OptionParser):
                 success = False
             progress_bar.report_progress(inputpath, success)
 
-    def ensurerecursiveoutputdirexists(self, options):
+    def ensurerecursiveoutputdirexists(self, options) -> None:
         if not self.isrecursive(options.output, "output"):
             if not options.output:
-                self.error(optparse.OptionValueError("No output directory given"))
+                self.error("No output directory given")
             try:
                 self.warning("Output directory does not exist. Attempting to create")
                 os.mkdir(options.output)
             except OSError:
-                self.error(
-                    optparse.OptionValueError(
-                        "Output directory does not exist, attempt to create failed"
-                    )
-                )
+                self.error("Output directory does not exist, attempt to create failed")
 
     @staticmethod
     def openinputfile(options, fullinputpath):
@@ -654,7 +671,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         """Opens a temporary output file."""
         return BytesIO()
 
-    def finalizetempoutputfile(self, options, outputfile, fulloutputpath):
+    def finalizetempoutputfile(self, options, outputfile, fulloutputpath) -> None:
         """Write the temp outputfile to its final destination."""
         outputfile.seek(0, 0)
         outputstring = outputfile.read()
@@ -672,7 +689,7 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def processfile(
         self, fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
-    ):
+    ) -> bool:
         """Process an individual file."""
         inputfile = self.openinputfile(options, fullinputpath)
         if fulloutputpath and fulloutputpath in {fullinputpath, fulltemplatepath}:
@@ -702,7 +719,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         return False
 
     @staticmethod
-    def mkdir(parent, subdir):
+    def mkdir(parent, subdir) -> None:
         """Makes a subdirectory (recursively if necessary)."""
         if not os.path.isdir(parent):
             raise ValueError(
@@ -715,7 +732,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             if not os.path.isdir(currentpath):
                 os.mkdir(currentpath)
 
-    def checkoutputsubdir(self, options, subdir):
+    def checkoutputsubdir(self, options, subdir) -> None:
         """
         Checks to see if subdir under options.output needs to be created,
         creates if necessary.
@@ -725,7 +742,7 @@ class RecursiveOptionParser(optparse.OptionParser):
             self.mkdir(options.output, subdir)
 
     @staticmethod
-    def isexcluded(options, inputpath):
+    def isexcluded(options, inputpath) -> bool:
         """Checks if this path has been excluded."""
         basename = os.path.basename(inputpath)
         for excludename in options.exclude:
@@ -778,14 +795,12 @@ class RecursiveOptionParser(optparse.OptionParser):
         return inputfiles
 
     @staticmethod
-    def splitext(pathname):
+    def splitext(pathname: str) -> tuple[str, str]:
         """
         Splits *pathname* into name and ext, and removes the extsep.
 
         :param pathname: A file path
-        :type pathname: string
         :return: root, ext
-        :rtype: tuple
         """
         root, ext = os.path.splitext(pathname)
         ext = ext.replace(os.extsep, "", 1)
