@@ -52,12 +52,8 @@ def parseheaderstring(input):
     return headervalues
 
 
-def tzstring():
-    """
-    Returns the timezone as a string in the format [+-]0000, eg +0200.
-
-    :rtype: str
-    """
+def tzstring() -> str:
+    """Returns the timezone as a string in the format [+-]0000, eg +0200."""
     tzoffset = time.altzone if time.daylight else time.timezone
 
     hours, minutes = time.gmtime(abs(tzoffset))[3:5]
@@ -73,13 +69,12 @@ def format_key(key: str) -> str:
     return key
 
 
-def update(existing, add=False, **kwargs):
+def update(existing: dict[str, str], add: bool = False, **kwargs) -> dict[str, str]:
     """
     Update an existing header dictionary with the values in kwargs, adding
     new values only if add is true.
 
     :return: Updated dictionary of header entries
-    :rtype: dict of strings
     """
     headerargs = {}
     fixedargs = cidict((format_key(key), value) for key, value in kwargs.items())
@@ -147,7 +142,7 @@ class poheader:
         plural_forms=None,
         report_msgid_bugs_to=None,
         **kwargs,
-    ):
+    ) -> dict[str, str]:
         """
         Create a header dictionary with useful defaults.
 
@@ -156,10 +151,9 @@ class poheader:
         or a value (datetime or string)
 
         :return: Dictionary with the header items
-        :rtype: dict of strings
         """
 
-        def format_date(key, value, fallback=None):
+        def format_date(key, value, fallback=None) -> None:
             if value is False and (fallback is not None):
                 defaultargs[key] = fallback
             elif value is True or (value is None and fallback is None):
@@ -256,7 +250,7 @@ class poheader:
             header.markfuzzy(False)  # TODO: check why we do this?
         return header
 
-    def _insert_header(self, header):
+    def _insert_header(self, header) -> None:
         # we should be using .addunit() or some equivalent in case the
         # unit needs to refer back to the store, etc. This might be
         # subtly broken for POXLIFF, since we don't duplicate the code
@@ -276,7 +270,7 @@ class poheader:
         plural = None if not plural or plural[0] == "EXPRESSION" else plural[0]
         return nplural, plural
 
-    def updateheaderplural(self, nplurals, plural):
+    def updateheaderplural(self, nplurals, plural) -> None:
         """Update the Plural-Form PO header."""
         if isinstance(nplurals, str):
             nplurals = int(nplurals)
@@ -294,14 +288,12 @@ class poheader:
           3. Analysing the 'Language-Team' entry.
         """
         header = self.parseheader()
-        lang = header.get("Language")
-        if lang is not None:
+        if lang := header.get("Language"):
             # pylint: disable-next=import-outside-toplevel
             from translate.lang.data import langcode_ire  # noqa: PLC0415
 
             if langcode_ire.match(lang):
                 return lang
-            lang = None
         if "X-Poedit-Language" in header:
             # pylint: disable-next=import-outside-toplevel
             from translate.lang import poedit  # noqa: PLC0415
@@ -318,21 +310,20 @@ class poheader:
             return guess_language(header.get("Language-Team"))
         return None
 
-    def settargetlanguage(self, lang):
+    def settargetlanguage(self, lang: str) -> None:
         """
         Set the target language in the header.
 
         This removes any custom Poedit headers if they exist.
 
         :param lang: the new target language code
-        :type lang: str
         """
         if isinstance(lang, str) and len(lang) > 1:
             self.updateheader(
                 add=True, Language=lang, X_Poedit_Language=None, X_Poedit_Country=None
             )
 
-    def getprojectstyle(self):
+    def getprojectstyle(self) -> str | None:
         """
         Return the project based on information in the header.
 
@@ -365,22 +356,21 @@ class poheader:
         # TODO Call some project guessing code and probably move all of the above there also
         return None
 
-    def setprojectstyle(self, project_style):
+    def setprojectstyle(self, project_style: str) -> None:
         """
         Set the project in the header.
 
         :param project_style: the new project
-        :type project_style: str
         """
         self.updateheader(add=True, X_Project_Style=project_style)
 
-    def mergeheaders(self, otherstore):
+    def mergeheaders(self, otherstore) -> None:
         """
         Merges another header with this header.
 
         This header is assumed to be the template.
 
-        :type otherstore: :class:`~translate.storage.base.TranslationStore`
+        :param otherstore: The other store to merge headers from.
         """
         newvalues = otherstore.parseheader()
         retain_list = (
@@ -397,7 +387,7 @@ class poheader:
         }
         self.updateheader(**retain)
 
-    def updatecontributor(self, name, email=None):
+    def updatecontributor(self, name: str, email: str | None = None) -> None:
         """Add contribution comments if necessary."""
         header = self.header()
         if not header:
